@@ -1,8 +1,8 @@
 package XS::Log;
-#Build  MD5 : pqGp7BciIcd99xq0PC7inQ
-#Build Time : 2025-09-20 09:24:04
-our $VERSION = 1.07;
-our $BUILDDATE = "2025-09-20";  #Build Time: 09:24:04
+#Build  MD5 : 9Scm+U7BCADWI+a+VZw8vg
+#Build Time : 2025-09-20 09:29:07
+our $VERSION = 1.08;
+our $BUILDDATE = "2025-09-20";  #Build Time: 09:29:07
 use strict;
 use warnings;
 use constant { 
@@ -301,19 +301,19 @@ B<XS::Log>是高效快速的日志模块，纯c语言开发，快速高效的IO
 
 屏幕输出结果：
 
-  [2025-09-18 18:44:38.983][INFO ] This is info1
-  [2025-09-18 18:44:38.983][INFO ] This is info2
-  [2025-09-18 18:44:38.983][INFO ] This is info4
-  [2025-09-18 18:44:38.983][INFO ] This is info5
-  [2025-09-18 18:44:38.983][WARN ] This is warning1
-  [2025-09-18 18:44:38.983][WARN ] This is warning2
-  [2025-09-18 18:44:38.983][ERROR] This is error1
-  [2025-09-18 18:44:38.983][ERROR] This is error2
-  [2025-09-18 18:44:38.983][INFO ] (/home/user/temp1.pl:38) Hello Alice, value=42
-  [2025-09-18 18:44:38.983][DEBUG] (/home/user/temp1.pl:39) Hello Alice, value=42
-  [2025-09-18 18:44:38.983][DEBUG] (/home/user/temp1.pl:40) Hello Alice, value=42
-  [2025-09-18 18:44:38.983][DEBUG] (/home/user/temp1.pl:41) Hello Alice, value=42
-  [2025-09-18 18:44:38.983][ERROR] (/home/user/temp1.pl:42) File not found: /tmp/test.txt
+  [2025-09-18 18:44:38.983][INF] This is info1
+  [2025-09-18 18:44:38.983][INF] This is info2
+  [2025-09-18 18:44:38.983][INF] This is info4
+  [2025-09-18 18:44:38.983][INF] This is info5
+  [2025-09-18 18:44:38.983][WRN] This is warning1
+  [2025-09-18 18:44:38.983][WRN] This is warning2
+  [2025-09-18 18:44:38.983][ERR] This is error1
+  [2025-09-18 18:44:38.983][ERR] This is error2
+  [2025-09-18 18:44:38.983][INF] (/home/user/temp1.pl:38) Hello Alice, value=42
+  [2025-09-18 18:44:38.983][DEB] (/home/user/temp1.pl:39) Hello Alice, value=42
+  [2025-09-18 18:44:38.983][DEB] (/home/user/temp1.pl:40) Hello Alice, value=42
+  [2025-09-18 18:44:38.983][DEB] (/home/user/temp1.pl:41) Hello Alice, value=42
+  [2025-09-18 18:44:38.983][ERR] (/home/user/temp1.pl:42) File not found: /tmp/test.txt
 
 =head2 例子2:/home/user/temp2.pl
 
@@ -366,14 +366,14 @@ B<XS::Log>是高效快速的日志模块，纯c语言开发，快速高效的IO
 
 屏幕输出结果：
 
-  [2025-09-18 18:46:32.013][INFO ] This is info1
-  [2025-09-18 18:46:32.013][INFO ] This is info2
-  [2025-09-18 18:46:32.013][INFO ] This is info4
-  [2025-09-18 18:46:32.013][INFO ] This is info5
-  [2025-09-18 18:46:32.013][WARN ] This is warning1
-  [2025-09-18 18:46:32.013][WARN ] This is warning2
-  [2025-09-18 18:46:32.013][ERROR] This is error1
-  [2025-09-18 18:46:32.013][ERROR] This is error2
+  [2025-09-18 18:46:32.013][INF] This is info1
+  [2025-09-18 18:46:32.013][INF] This is info2
+  [2025-09-18 18:46:32.013][INF] This is info4
+  [2025-09-18 18:46:32.013][INF] This is info5
+  [2025-09-18 18:46:32.013][WRN] This is warning1
+  [2025-09-18 18:46:32.013][WRN] This is warning2
+  [2025-09-18 18:46:32.013][ERR] This is error1
+  [2025-09-18 18:46:32.013][ERR] This is error2
 
 =cut
 
